@@ -44,11 +44,15 @@ from tipg.dependencies import (
 )
 from tipg.errors import MissingGeometryColumn, NoPrimaryKey, NotFound
 from tipg.resources.enums import MediaType
-from tipg.resources.response import GeoJSONResponse, SchemaJSONResponse, orjsonDumps
+from tipg.resources.response import (
+    GeoJSONResponse,
+    ORJSONResponse,
+    SchemaJSONResponse,
+    orjsonDumps,
+)
 from tipg.settings import FeaturesSettings, MVTSettings, TMSSettings
 
 from fastapi import APIRouter, Depends, Path, Query
-from fastapi.responses import ORJSONResponse
 
 from starlette.datastructures import QueryParams
 from starlette.requests import Request
@@ -596,17 +600,17 @@ class OGCFeaturesFactory(EndpointsFactory):
                     )
                     for collection in collection_list["collections"]
                 ],
-            )
+            ).model_dump(exclude_none=True, mode="json")
 
             if output_type == MediaType.html:
                 return self._create_html_response(
                     request,
-                    data.model_dump(exclude_none=True, mode="json"),
+                    data,
                     template_name="collections",
                     title="Collections list",
                 )
 
-            return data
+            return ORJSONResponse(data)
 
     def _collection_route(self):
         @self.router.get(
@@ -689,17 +693,17 @@ class OGCFeaturesFactory(EndpointsFactory):
                     ),
                     *self._additional_collection_tiles_links(request, collection),
                 ],
-            )
+            ).model_dump(exclude_none=True, mode="json")
 
             if output_type == MediaType.html:
                 return self._create_html_response(
                     request,
-                    data.model_dump(exclude_none=True, mode="json"),
+                    data,
                     template_name="collection",
                     title=f"{collection.id} collection",
                 )
 
-            return data
+            return ORJSONResponse(data)
 
     def _queryables_route(self):
         @self.router.get(
@@ -735,17 +739,17 @@ class OGCFeaturesFactory(EndpointsFactory):
                 title=collection.id,
                 link=self_url + qs,
                 properties=collection.queryables,
-            )
+            ).model_dump(exclude_none=True, mode="json", by_alias=True)
 
             if output_type == MediaType.html:
                 return self._create_html_response(
                     request,
-                    data.model_dump(exclude_none=True, mode="json"),
+                    data,
                     template_name="queryables",
                     title=f"{collection.id} queryables",
                 )
 
-            return data
+            return SchemaJSONResponse(data)
 
     def _items_route(self):  # noqa: C901
         @self.router.get(
@@ -1250,7 +1254,7 @@ class OGCTilesFactory(EndpointsFactory):
                     "tilematrixsets",
                 ),
                 type=MediaType.json,
-                rel="data",
+                rel="http://www.opengis.net/def/rel/ogc/1.0/tiling-schemes",
             ),
             model.Link(
                 title="TileMatrixSet (Template URL)",
@@ -1311,8 +1315,6 @@ class OGCTilesFactory(EndpointsFactory):
                                     "tilematrixset",
                                     tileMatrixSetId=tms_id,
                                 ),
-                                rel="http://www.opengis.net/def/rel/ogc/1.0/tiling-schemes",
-                                type=MediaType.json,
                             )
                         ],
                     )
@@ -1431,7 +1433,7 @@ class OGCTilesFactory(EndpointsFactory):
                                         "tilematrixset",
                                         tileMatrixSetId=tms,
                                     ),
-                                    "rel": "http://www.opengis.net/def/rel/ogc/1.0/tiling-schemes",
+                                    "rel": "http://www.opengis.net/def/rel/ogc/1.0/tiling-scheme",
                                     "type": "application/json",
                                     "title": f"Definition of '{tms}' tileMatrixSet",
                                 },
@@ -1542,7 +1544,7 @@ class OGCTilesFactory(EndpointsFactory):
                         "tilematrixset",
                         tileMatrixSetId=tileMatrixSetId,
                     ),
-                    "rel": "http://www.opengis.net/def/rel/ogc/1.0/tiling-schemes",
+                    "rel": "http://www.opengis.net/def/rel/ogc/1.0/tiling-scheme",
                     "type": "application/json",
                     "title": f"Definition of '{tileMatrixSetId}' tileMatrixSet",
                 },
